<!DOCTYPE html>
<html>
  <head>
    <link href="https://fonts.googleapis.com/css?family=Arvo|Lato|Literata|Montserrat|Raleway&display=swap" rel="stylesheet"> 
    <link rel="stylesheet" type="text/css" href="/static/base.css">
    <script src="/static/base.js"></script> 
  </head>
  <body>
    <div>
      What name is in valuable?
    </div>
    <style>
      body{
	  background-color: white;
      }
    </style>
  </body>
</html>
